@@ -1,7 +1,7 @@
 #!/usr/bin/env python1.5
 
 # GNU Solfege - eartraining for GNOME
-# Copyright (C) 2000-2001  Tom Cato Amundsen
+# Copyright (C) 2000, 2001  Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -19,17 +19,21 @@
 
 # This script is used to launch Solfege when running
 # it from the source dir without installing.
+#from __future__ import nested_scopes
 
 import sys
 import src.configureoutput
 
-
-#sys.path.insert(0, "/home/tom/lib/python2.0/site-packages")
-
 if not src.configureoutput.WITH_GNOME:
     sys.path.insert(0, "gnomeemu")
 
 import src.i18n
 src.i18n.initialise("share/locale")
-import src.mainwin
+
+import __main__, time
+__main__._st = time.clock()
+if '--txtui' in sys.argv:
+    import src.txtui
+else:
+    import src.mainwin
 
