@@ -18,7 +18,7 @@
 import sys
 
 if '--inithack' in sys.argv:
-    import src.inithack
+    import inithack
     del sys.argv[sys.argv.index('--inithack')]
 
 import src.rcfile
